You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openjpa.apache.org by mi...@apache.org on 2009/07/27 23:37:31 UTC

svn commit: r798295 - /openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java

Author: mikedd
Date: Mon Jul 27 21:37:31 2009
New Revision: 798295

URL: http://svn.apache.org/viewvc?rev=798295&view=rev
Log:
OPENJPA-991: Disabling unreliable testcase in 1.2.x

Modified:
    openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java

Modified: openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java
URL: http://svn.apache.org/viewvc/openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java?rev=798295&r1=798294&r2=798295&view=diff
==============================================================================
--- openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java (original)
+++ openjpa/branches/1.2.x/openjpa-persistence-jdbc/src/test/java/org/apache/openjpa/persistence/exception/TestException.java Mon Jul 27 21:37:31 2009
@@ -48,10 +48,11 @@
     }
     
 	/**
 	 * Tests that when Optimistic transaction consistency is violated, the
 	 * exception thrown is an instance of javax.persistence.OptimisticException.
 	 */
-	public void testThrowsOptimisticException() {
+	public void disabledTestThrowsOptimisticException() {
 		EntityManager em1 = emf.createEntityManager();
 		EntityManager em2 = emf.createEntityManager();
 		assertNotEquals(em1, em2);
@@ -48,10 +48,11 @@
     
 	/**
-	 * Tests that when Optimistic transaction consistency is violated, the
-	 * exception thrown is an instance of javax.persistence.OptimisticException.
+	 * <p>Tests that when Optimistic transaction consistency is violated, the
+	 * exception thrown is an instance of javax.persistence.OptimisticException.</p>
+	 * <p>Disabled pending resolution of OPENJPA-991</p>
 	 */